<?php

	// Glide Remote Integration Tool - Bulk import script (run once to import all relevant clients to Glide)
	// Written by Oli Norwell

	include_once("integ_funcs.php");

	// Output a title
	echo "Glide Remote Integration tool - bulk import script\n";
	echo SCRIPT_VERSION." - ".SCRIPT_DATE."\n\n";

	if(!@include_once("credentials.php"))
	{
		reportGeneralError("Critical error: credentials.php not found");
		reportGeneralError("You need to rename the credentials_example.php file and then enter data into the required fields.");
		die();
	}

	if($GLOBALS['target_system'] != 1 && $GLOBALS['target_system'] != 2)
	{
		reportGeneralError("Critical error: Please set the target integration system in credentials.php (either 1 = CCH  2 = Digita)");
		die();
	}

	// Get Glide API key
	$gkey = $GLOBALS['gkey'];

	if(strlen($gkey) == 0)
	{
		reportGeneralWarning("No API key supplied - your Glide system will not be updated");
		$GLOBALS['config_no_glide_connection'] = 1;
	}

	$db2 = null;

	try
	{
		echo "Attempting to connect to SQL Server database...\n";
		$db2 = new PDO("sqlsrv:server=".$GLOBALS['sql_servername']." ; Database=".$GLOBALS['sql_dbase'],$GLOBALS['sql_user'],$GLOBALS['sql_password']);
		$db2->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION );
	}
	catch(PDOException $e)
	{
		reportGeneralError("Integration Connection Issue: ".$e->getMessage());
		
		$db2 = null;

		reportGeneralError("There was a critical error connecting to SQL Server, please run the SQL Server Test Connection script");
		die();
	}

	// If connection is active...
	if($db2)
	{
		reportInfo("Connected to database....");


		if($GLOBALS['target_system'] == 1) // CCH
		{

		// We are connected, so do the update

		// Step 0.1 Create partner lookup table firstly....
		$sql = "USE ".$GLOBALS['sql_dbase'];
		try { $result = $db2->query($sql); } catch(PDOException $e) { reportGeneralError($e->getMessage()); }

		unset($partnerEmployeeIDs);
		$partnerEmployeeIDs = array();

		$sql1 = "SELECT b.PartnerId AS par, b.EmployeeID AS prn FROM ContactPartnerHistory a, Partner b WHERE b.PartnerID = a.PartnerID";
		$stm1 = $db2->prepare($sql1);
		try { $stm1->execute(); } catch(PDOException $e) { reportGeneralError($e->getMessage()); }

		while($rowp1 = $stm1->fetch())
		{
			$pid = $rowp1['par'];
			$partnerEmployeeIDs[$pid] = $rowp1['prn'];
		}



		// Read users into a table
		$glide_users = array();

		if($GLOBALS['config_no_glide_connection'] == 0) // If we are connecting to Glide
		{

		// Step 1 - Get all users on Glide
		$command = "/users/list";						// The API command that we will be using
		$baseurl = $GLOBALS['glide_api_url'];					// Create the request URL
		$url = $baseurl.$command."?key=".$gkey."&returnFormat=1";		// Build the URL that we will call
		$ch = curl_init();							// Initiate curl

		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
		curl_setopt($ch, CURLOPT_URL,$url);					// Set the url that we wish to call
		$curl_result = curl_exec($ch);						// Execute our request (call Glide and make our request)
		curl_close($ch);							// Close down cURL - as we have done what we wished to do
		$array_result = array();						// PHP array to place our decoded data into
		$array_result = (array)json_decode($curl_result, true);

		if(isset($array_result['StatusReport']))
		{
			echo $array_result['StatusReport']."\n";
		}

		$x = 0;
		foreach($array_result AS $usr)
		{
			if(is_array($usr))
			{
				foreach($usr AS $u)
				{
					$glide_users[] = $u;
					$x++;
				}
			}
		}

		echo "Retrieving users from CCH database...\n";

		// Step 2. Grab users from CCH [*** ask individual clients if they can specify easily ***]
		$stm = $db2->prepare("SELECT EmployeeID, FNameTemp, SNameTemp, EMail, EmployeeCode, Inactive, ContactID FROM Employee WHERE Inactive = 0");
		try { $stm->execute(); } catch(PDOException $e) { echo $e->getMessage(); $error = 1; echo "Error connecting to server....\n"; exit(); }
		$result = $stm->fetchAll(PDO::FETCH_ASSOC);

		$str = "";
		foreach($result AS $row) // Look through all CCH staff
		{
			
			$isGlideImportable = 0;


			$filterUsersByExtraField = $GLOBALS['config_filterusers'];
			$userExtraFieldID = $GLOBALS['config_filterusers_fieldid'];

			if($filterUsersByExtraField == 1)
			{
				// Firstly look to see if they should be included in Glide
				$stm2 = $db2->prepare("SELECT xe.EmployeeID  FROM ExtraEmployee xe, ExtraValue xv WHERE xe.EmployeeID = '".$row['EmployeeID']."' AND xe.ExtraValueID = xv.ExtraValueID AND xv.ExtraFieldID = ".intval($userExtraFieldID)." AND xv.Value = 'Yes'");
				try { $stm2->execute(); } catch(PDOException $e) { echo $e->getMessage(); $error = 1; echo "Error connecting to server....\n"; exit(); }
				$result2 = $stm2->fetchAll(PDO::FETCH_ASSOC);


				foreach($result2 AS $row2)
				{
					$isGlideImportable = 1;
				}
			}
			else
			{
				$isGlideImportable = 1;
			}




			if($isGlideImportable == 1)
			{
				echo "User: ".$row['EmployeeID']." is to be imported (".$row['FNameTemp']." ".$row['SNameTemp'].")...\n";

			$xx = 0;

			// For each employee look to see if they are already in Glide
			$found = 0;
			foreach($glide_users AS $gu)
			{
				foreach($gu AS $gld)
				{
					if(isset($gld['AlternateID']))
					{
						if($gld['AlternateID'] == $row['EmployeeID'])
						{
							echo "Found user ".$row['EmployeeID']." is Glide ".$gld['AlternateID']." ".$gld['Name']." ".$gld['Surname']."\n";

							$found = 1;
						}

						// ---------------------------------------------------------------------------
						// Not found by alt ID but matched on email - need to update alt ID on Glide
						if($found == 0)
						{
							if($gld['Email'] == $row['EMail'])
							{

							}
						}
						// ---------------------------------------------------------------------------


					}

					$xx++;
				}
			}

			if($found == 0)
			{

				$createUsers = 1;

				if($createUsers == 1 && $GLOBALS['config_no_glide_connection'] == 0) //If we're connecting 2G
				{
				reportInfo("User ".$row['EmployeeID']." was not found on Glide after $xx (".$row['FNameTemp']." ".$row['SNameTemp'].")");

				// use the API to create the user
				// CONNECT TO THE GLIDE API

				$command = "/users/create";					// The API command that we will be using
				$baseurl = $GLOBALS['glide_api_url'];				// Create the request URL
				$url = $baseurl.$command."?key=".$gkey."&returnFormat=1";	// Build the URL that we will call

				$ch = curl_init();						// Initiate curl
				curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
				curl_setopt($ch, CURLOPT_URL,$url);				// Set the url that we wish to call

				$fields = null;

				$inicalced = "--";
				if(strlen($row['FNameTemp']) > 0 && strlen($row['SNameTemp']) > 0)
				{
					$fn = $row['FNameTemp'];
					$sn = $row['SNameTemp'];
					$inicalced = $fn[0].$sn[0];
				}

				$em = "";
				if(isset($row['EMail'])) $em = $row['EMail'];

				// Now we build up a PHP array with the data for our new client - these are the fields that we can supply
				$fields = array('firstname' => rawurlencode($row['FNameTemp']),
							  'surname' => rawurlencode($row['SNameTemp']),
							  'email' => rawurlencode($em),
							  'altid' => rawurlencode($row['EmployeeID'])		);

			        // Turn the above array into a string that we can pass as POST fields
				$fields_string = "";
				foreach($fields as $key=>$value) { $fields_string .= $key.'='.$value.'&'; }
				$fields_string = rtrim($fields_string, '&');
				curl_setopt($ch,CURLOPT_POST, count($fields));			// Set the cURL options for POST data
				curl_setopt($ch,CURLOPT_POSTFIELDS, $fields_string);

				$curl_result = curl_exec($ch);			// Execute our request (call Glide and make our request)
				curl_close($ch);		// Close down cURL - as we have done what we wished to do

				$array_result = array();	// PHP array to place our decoded data into
				$array_result = (array)json_decode($curl_result, true);

				if(isset($array_result['StatusReport']))
				{
					echo $array_result['StatusReport']."\n";
				}

				if(isset($array_result['StatusReport']))
				{
					// --------------------------------------------------------------------------------------
					if($array_result['StatusReport'] == "User already exists")
					{
						// Need to get ID for later
						$GID = -1;
						foreach($array_result['Infos'] AS $usrx)
						{
							if(is_array($usrx))
							{
								foreach($usrx AS $u)
								{
									$GID = $u['GlideID'];
								}
							}
						}

						// add them to the Glide list we hold for later
						if($GID != -1)
						{
							$newgu = array();
							$newgu['ID'] = $GID;
							$newgu['Name'] = "---";
							$newgu['Surname'] = "---";
							$newgu['Initials'] = "---";
							$newgu['Role'] = 11;
							$newgu['ClearanceLevel'] = 11;
							$newgu['Email'] = "t@t.com";
							$newgu['Status'] = 1;
							$newgu['Deleted'] = 0;
							$newgu['AlternateID'] = $row['EmployeeID'];

							$glide_users[0][] = $newgu;


							// Also update this Glide user with the ALT ID

							// use the API to create the user
							// CONNECT TO THE GLIDE API

							$command = "/users/update";						// The API command that we will be using
							$baseurl = $GLOBALS['glide_api_url'];					// Create the request URL
							$url = $baseurl.$command."?key=".$gkey."&returnFormat=1";		// Build the URL that we will call

							$ch = curl_init();							// Initiate curl
							curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
							curl_setopt($ch, CURLOPT_URL,$url);					// Set the url that we wish to call

							$fields = null;

							// Now we build up a PHP array with the data for our new client - these are the fields that we can supply
							$fields = array('id' => rawurlencode($GID),
										'altid' => rawurlencode($row['EmployeeID'])		);

							// Turn the above array into a string that we can pass as POST fields
							$fields_string = "";
							foreach($fields as $key=>$value) { $fields_string .= $key.'='.$value.'&'; }
							$fields_string = rtrim($fields_string, '&');
							curl_setopt($ch,CURLOPT_POST, count($fields));			// Set the cURL options for POST data
							curl_setopt($ch,CURLOPT_POSTFIELDS, $fields_string);

							$curl_result = curl_exec($ch);			// Execute our request (call Glide and make our request)
							curl_close($ch);		// Close down cURL - as we have done what we wished to do

							$array_result = array();	// PHP array to place our decoded data into
							$array_result = (array)json_decode($curl_result, true);

							if(isset($array_result['StatusReport']))
							{
								echo $array_result['StatusReport']."\n";
							}

							// -----------------------------


						}

						reportInfo("Existing Glide user ".$em." matched on email (".$GID.") ");	
					}
					// --------------------------------------------------------------------------------
				
					if($array_result['StatusReport'] == "User created successfully")
					{
						$GID = -1;
						foreach($array_result AS $usrx)
						{
							if(is_array($usrx))
							{
								foreach($usrx AS $u)
								{
									$GID = $u['GlideID'];
								}
							}
						}

						// add them to the Glide list we hold for later
						if($GID != -1)
						{
							$newgu = array();
							$newgu['ID'] = $GID;
							$newgu['Name'] = "---";
							$newgu['Surname'] = "---";
							$newgu['Initials'] = "---";
							$newgu['Role'] = 11;
							$newgu['ClearanceLevel'] = 11;
							$newgu['Email'] = "t@t.com";
							$newgu['Status'] = 1;
							$newgu['Deleted'] = 0;
							$newgu['AlternateID'] = $row['EmployeeID'];

							$glide_users[0][] = $newgu;
//							echo "newadded to our GU list";
						}

						reportInfo("New user ".$em." created in Glide (".$GID.") ");
					}
					else
					{
						print_r($array_result);
					}
				}
				


				}
			}

			}
		}


		}
		else
		{
			reportGeneralWarning("Glide connection not active so cannot pull list of users");
		}

		// Switch now to the main CCH database
		$clientCount = 0;
		$clientIgnoredCount = 0;
		$sql = "USE ".$GLOBALS['sql_dbase'];
		try { $result = $db2->query($sql); } catch(PDOException $e) { reportGeneralError($e->getMessage()); die(); }

		// SQL - for initial pull in everything [not for normal remote grab code - just for main import]
		$sql = "SELECT a.ContactID AS ContactID, b.pref AS Pref, b.FName AS Fname, b.LName AS Lname, b.Email AS EmailAdd, b.Tel AS Landline, b.Mobile AS TelPhone, a.ClientCode AS ClientCode, c.Name AS ClientType, a.Closed AS Closed, d.CompanyRegistrationNo AS CompanyRegistrationNo, b.BusinessTypeId AS bustypid, e.ContactType AS contactTypeString FROM Client a, Contact b, BusinessType c, ClientSupplier d, ContactType e WHERE a.ContactID = b.ContactID AND a.ContactID = d.ContactID AND b.BusinessTypeId = c.BusinessTypeId AND e.ContactTypeID = b.ContactTypeID ".$GLOBALS['sql_cch_additional_client_filter'];
		$stm = $db2->prepare($sql);

		$doneCount = 0;
		$str = "";

		try { $stm->execute(); } catch(PDOException $e) { reportGeneralError($e->getMessage()); reportGeneralError("SQL error when running query for clients"); reportGeneralError("SQL: ".$sql); die(); }
		$result = $stm->fetchAll(PDO::FETCH_ASSOC);

		$rcnt = 0;
		$rcntA = 0;
		
		$missingInfo = "";
		
		foreach($result AS $row)
		{
			$rcntA++; // disabled moved down
			reportInfo($rcntA.". code: ".$row['ClientCode']." - contact ID: ".$row['ContactID']);
			$client_Partner = -1;

			// Manager field (also a responsibility type)
			$client_Manager = -1;

			// Addition custom fields
			//$client_XManagerA = NULL;
			//$client_XManager = -1;



			// Email/telephone number
			$client_Email = $row['EmailAdd'];
			$client_Tel = $row['TelPhone'];

			$findme   = '@';
			$pos = strpos($client_Email, $findme);

			if ($pos === false) 	// wipe email if no @
			{
			  $client_Email = ""; 
			}		

			if($client_Tel == "NULL")
			{
				$client_Tel = "";
			}
			// ----------------------



			$found = 1; // no filter right now

			// *** It's possible here to add a query to determine if this client should be dealt with or not

			if($found == 1)
			{
				$client_Type = -1;
				$client_Closed = 0;

				// Grab partner [from ContactPartnerHistory table]
				$sql1 = "SELECT c.EmployeeID AS id, c.EmployeeCode AS Ini FROM ContactPartnerHistory a, Partner b, Employee c WHERE a.ContactId = '".$row['ContactID']."' AND b.PartnerID = a.PartnerID AND a.EndDate IS NULL AND b.EmployeeID = c.EmployeeID";
				$stm1 = $db2->prepare($sql1);
				try { $stm1->execute(); $result1x = $stm1->fetchAll(PDO::FETCH_ASSOC); } catch(PDOException $e) { reportGeneralError($e->getMessage()); die(); }

				foreach($result1x AS $row3)
				{
					$client_Partner = $row3['id']; // and we can leave as alternate ID

					// *** SPECIAL FIX TO CONVERT SOME USERS CAN GO HERE (for example if multiple CCH users need to be 1 user in Glide)
					////// e.g. if($client_Partner == 508) $client_Partner = 505;

					reportInfo("Client Partner: ".$client_Partner." (".$row3['Ini'].")");
				}


				$existCustomStaffFields = 1;

				if($existCustomStaffFields == 1)
				{
				
					// Grab whatever staff we wish to get [this will vary from client to client]
					$sql2 = "SELECT b.EmployeeID AS id, b.EmployeeCode AS Ini, c.Description AS Des, a.ResponsibilityTypeID AS Pos  FROM ContactTeam a, Employee b, ResponsibilityType c WHERE a.ContactId = '".$row['ContactID']."' AND b.EmployeeID = a.EmployeeID AND c.ResponsibilityTypeID = a.ResponsibilityTypeID";
					$stm2 = $db2->prepare($sql2);
					try { $stm2->execute(); } catch(PDOException $e) { reportGeneralError($e->getMessage()); die(); }
;
					$result2 = $stm2->fetchAll(PDO::FETCH_ASSOC);
					
					$YESDOIT = 0;
					
					foreach($result2 AS $row2)
					{
						// ***********************************************
						if($row2['Pos'] == 22) // MANAGER (and we can leave as alternate ID)
						{
							$client_Manager = $row2['id'];
							reportInfo("Client Manager: ".$client_Manager." (".$row2['Ini'].")");
						}

						// ************ Add code here for custom positions	
			
					}

				}
				

				// Ensure empty values in CCH result in the data being removed from Glide
				
				// from the special partners table
				if($client_Partner == NULL) $client_Partner = -500;

				// from the responsibilties table
				if($existCustomStaffFields == 1)
				{
					if($client_Manager == NULL) $client_Manager = -500; // remember this appears in the additional fields table
				// ********* from the responsibilities table - Additional custom fields
				//
				}


				$clientTypeRead = $row['contactTypeString'];
				
				$optct = -1;	// Set the corporation tax option based on client type
		
				
				// Read client type from database field - note: this will change based on client 
				if($clientTypeRead == "Other Person") { $client_Type = 50; $optct = 0; 				$uni1_d1a = 0; $uni1_d2a = 0; $uni2_d1a = 1;	$uni3_d1a = 0;	} 
				else if($clientTypeRead == "Other Organisation") { $client_Type = 12; $optct = 1; 				$uni1_d1a = 1; $uni1_d2a = 1; $uni2_d1a = 0;	$uni3_d1a = 1;	} 
				else if($clientTypeRead == "Limited") { $client_Type = 1; $optct = 1; 				$uni1_d1a = 1; $uni1_d2a = 1; $uni2_d1a = 0;	$uni3_d1a = 1;	} 
				else if($clientTypeRead == "Not for profit organisation") { $client_Type = 6; $optct = 0; 				$uni1_d1a = 1; $uni1_d2a = 1; $uni2_d1a = 0;	$uni3_d1a = 1;	} 
				else if($clientTypeRead == "Trust") { $client_Type = 10; $optct = 0; 				$uni1_d1a = 1; $uni1_d2a = 1; $uni2_d1a = 0;	$uni3_d1a = 1;	} 
				else if($clientTypeRead == "Partnership") { $client_Type = 4; $optct = 0; 				$uni1_d1a = 1; $uni1_d2a = 1; $uni2_d1a = 0;	$uni3_d1a = 1;	} 
				else if($clientTypeRead == "LLP") { $client_Type = 5; $optct = 1; 				$uni1_d1a = 1; $uni1_d2a = 1; $uni2_d1a = 0;	$uni3_d1a = 1;	} 
				else if($clientTypeRead == "Sole Trade") { $client_Type = 3; $optct = 0; 				$uni1_d1a = 1; $uni1_d2a = 1; $uni2_d1a = 0;	$uni3_d1a = 1;	} 
				else {  $client_Type = -1;	} 


				$chNumBlock = 0;	
				// OPTIONAL - block based on no company registration number for certain Glide client types
				if($client_Type == 1 || $client_Type == 2 || $client_Type == 5 || $client_Type == 7)
				{
					if(strlen($row['CompanyRegistrationNo']) < 3) // no CH number
					{
						reportInfo("(CH num: ".$row['CompanyRegistrationNo'].") [".$row['ContactID']."] [".$row['Lname']."] Not acting for limited company because it does not have a CH code!!!");
						$client_Type = -1;
						$chNumBlock = 1;
					}
				}
				


				// Get if client is closed or not in CCH
				if(strlen($row['Closed']) > 2)
				{
					reportInfo("Issue: Client closed so IGNORE - ".$row['Fname']." ".$row['Lname']." - ".$row['ClientCode']);
					$clientIgnoredCount++;
					$client_Closed = 1;
				}
				else
				{
					$client_Closed = 0;
				}
				
				// If not type or closed, then ignore
				if($client_Type == -1)
				{
					if($chNumBlock == 0) reportInfo("Issue: No matched client type found so IGNORE - ".$row['Fname']." ".$row['Lname']." - ".$row['ClientCode']);
					$clientIgnoredCount++;
				}
				else if($client_Closed == 0)
				{
					$rcnt++;
					reportInfo("Client acceptable: Code: ".$row['ClientCode']." - Contact ID: ".$row['ContactID']);
				}

				
				// if we are importing then go and do it
				if($client_Closed == 0 && $client_Type != -1 && $GLOBALS['config_no_glide_connection'] == 0)
				{
					$clientCount++;
					
					$ar_next_due_fromch = "";
					// For limited company - do CH lookup
					$chNum = $row['CompanyRegistrationNo'];
					if(strlen($chNum) < 3) $chNum = "";
					
					$name = $row['Lname'];
					$name_title = $row['Pref'];
					$name_first = $row['Fname'];
					
					// *** added so that sole trader 'companies' can get full name in their name
					if($client_Type != 50)
					{
						if(strlen($name_first) > 0)
						{
							$name = $row['Fname']." ".$row['Lname'];
						}
					}
					// ***

					
					$uniqueID = $row['ContactID'];
					$type = $client_Type;
					$clientCode = $row['ClientCode'];
					echo "CH Num: ".$chNum."\n";

					reportInfo("Sending client data to Glide API...");
					
					// CONNECT TO THE GLIDE API
					$command = "/clients/create";				// The API command that we will be using
					$baseurl = $GLOBALS['glide_api_url'];		// Create the request URL
					$url = $baseurl.$command."?key=".$gkey."&returnFormat=1";	// Build the URL that we will call

					$ch = curl_init();									// Initiate curl
					curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
					curl_setopt($ch, CURLOPT_URL,$url);					// Set the url that we wish to call

					$fields = null;
					
					// Now we build up a PHP array with the data for our new client - these are the fields that we can supply
					$fields = array(		'name' => rawurlencode($name),
											'title' => rawurlencode($name_title),
											'firstn' => rawurlencode($name_first),
											'code' => rawurlencode($uniqueID),
											'type' => rawurlencode($type),
											'ucode' => rawurlencode($clientCode),
											'pari' => rawurlencode($client_Partner),
											'mani' => rawurlencode($client_Manager),
											'opt_corptax' => rawurlencode($optct),
											'opt_chnum' => rawurlencode($chNum)
											);

										
					// Turn the above array into a string that we can pass as POST fields
					$fields_string = "";
					foreach($fields as $key=>$value) { $fields_string .= $key.'='.$value.'&'; }
					$fields_string = rtrim($fields_string, '&');
					curl_setopt($ch,CURLOPT_POST, count($fields));			// Set the cURL options for POST data
					curl_setopt($ch,CURLOPT_POSTFIELDS, $fields_string);

					$curl_result = curl_exec($ch);			// Execute our request (call Glide and make our request)
					curl_close($ch);		// Close down cURL - as we have done what we wished to do

					
					
					$array_result = array();	// PHP array to place our decoded data into
					$array_result = (array)json_decode($curl_result, true);

					//print_r($curl_result);
					//print_r($array_result);
					
					if(isset($array_result['StatusReport']))
					{
						echo $array_result['StatusReport']."\n\n";
						
						if($array_result['StatusReport'] == "Already Exists")
						{
							reportInfo("Client already exists so update it...");

							// Already exists... so update
							$command = "/clients_by_id2/update";				// The API command that we will be using
							$baseurl = $GLOBALS['glide_api_url'];		// Create the request URL
							$url = $baseurl.$command."?key=".$gkey."&returnFormat=1";	// Build the URL that we will call

							$ch = curl_init();									// Initiate curl
							curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
							curl_setopt($ch, CURLOPT_URL,$url);					// Set the url that we wish to call

							// Now we build up a PHP array with the data for our new client - these are the fields that we will supply
							// Note: You may wish to supply more or less data, see the documentation for full details
							$fields = array(		'name' => rawurlencode($name),
												'title' => rawurlencode($name_title),
												'firstn' => rawurlencode($name_first),
												'code' => rawurlencode($uniqueID),
												'type' => rawurlencode($type),
												'ucode' => rawurlencode($clientCode),
												'pari' => rawurlencode($client_Partner),
												'mani' => rawurlencode($client_Manager),
												'opt_corptax' => rawurlencode($optct),
												'opt_chnum' => rawurlencode($chNum)
											);

							// Turn the above array into a string that we can pass as POST fields
							$fields_string = "";
							foreach($fields as $key=>$value) { $fields_string .= $key.'='.$value.'&'; }
							$fields_string = rtrim($fields_string, '&');
							curl_setopt($ch,CURLOPT_POST, count($fields));			// Set the cURL options for POST data
							curl_setopt($ch,CURLOPT_POSTFIELDS, $fields_string);

							$curl_result = curl_exec($ch);			// Execute our request (call Glide and make our request)
							curl_close($ch);		// Close down cURL - as we have done what we wished to do

							$array_result = array();	// PHP array to place our decoded data into
							$array_result = (array)json_decode($curl_result, true);

							if(isset($array_result['StatusReport']))
							{
								echo $array_result['StatusReport'];
							}
						}
						else if($array_result['StatusReport'] == "Client created successfully") // It was actually created
						{
							reportInfo("Client has been created successfully in Glide...");
						}
					}

					echo "\n";


					// Tel/Email if enabled
					if($GLOBALS['cch_sendtoglide_client_email_enabled'] == true)
					{
						if(strlen($client_Email) > 1) // 
						{
							echo "Setting Email: ".$client_Email."...";
							
							$fieldID = $GLOBALS['cch_sendtoglide_client_email_glide_fieldid']; ///"221"; 	// *** SET 
							$value = rawurlencode($client_Email); // This is the data to insert into the field, note we need to use urlencode
							$command = "/clients_by_id3/$uniqueID/set/$fieldID/$value";				// The API command that we will be using
							$baseurl = "https://www.whatsglide.com/i/api/api.php";		// Create the request URL
							$url = $baseurl.$command."?key=".$gkey."&returnFormat=1";	// Build the URL that we will call

							$ch = curl_init();									// Initiate curl
							curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false); 	// Disable SSL verification
							curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
							curl_setopt($ch, CURLOPT_URL,$url);					// Set the url that we wish to call

							$curl_result = curl_exec($ch);			// Execute our request (call Glide and make our request)
							
							echo $curl_result;
							
							curl_close($ch);		// Close down cURL - as we have done what we wished to do

							$array_result = array();	// PHP array to place our decoded data into
							$array_result = (array)json_decode($curl_result, true);

							if(isset($array_result['Status']))
							{
	//							echo $array_result['Status'];
							}
							echo "\n";
						}
					}

					if($GLOBALS['cch_sendtoglide_client_tel_enabled'] == true)
					{
						if(strlen($client_Tel) > 1) // 
						{
							echo "Setting Tel: ".$client_Tel."...";
							
							$fieldID = $GLOBALS['cch_sendtoglide_client_tel_glide_fieldid']; ///"220"; 	// *** SET 
							$value = rawurlencode($client_Tel); // This is the data to insert into the field, note we need to use urlencode
							$command = "/clients_by_id3/$uniqueID/set/$fieldID/$value";				// The API command that we will be using
							$baseurl = "https://www.whatsglide.com/i/api/api.php";		// Create the request URL
							$url = $baseurl.$command."?key=".$gkey."&returnFormat=1";	// Build the URL that we will call

							$ch = curl_init();									// Initiate curl
							curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false); 	// Disable SSL verification
							curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
							curl_setopt($ch, CURLOPT_URL,$url);					// Set the url that we wish to call

							$curl_result = curl_exec($ch);			// Execute our request (call Glide and make our request)
							
							echo $curl_result;
							
							curl_close($ch);		// Close down cURL - as we have done what we wished to do

							$array_result = array();	// PHP array to place our decoded data into
							$array_result = (array)json_decode($curl_result, true);

							if(isset($array_result['Status']))
							{
	//							echo $array_result['Status'];
							}
							echo "\n";
						}
					}










					// **** Location for additional fields setting code

					// ** to add here if needed
			
				}
				else
				{
					// not importing this client...
				}
			}
			else 
			{
				///
			}
		}


		} // end of CCH integration
		else if($GLOBALS['target_system'] == 2) // Digita
		{

			// Not added yet

		}
	}

	reportInfo("Script completed....");
?>
